<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AudioCart</name>
    <message>
        <source>Copying audio...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit
Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit
Markers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDCatch Event Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clipboard Empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clipboard is currently empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[new cart]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No audio is present in the cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One or more cuts are used in one or more RDCatch events!
Do you still want to delete?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete audio for cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No data copied - you must select a single cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must select a single cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SHA1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>not available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Played</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source># of Plays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ingest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Outcue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daypart Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daypart End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ord</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CdRipper</name>
    <message>
        <source>Artist:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Rip
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ripping this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Data Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Importer Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Ripper Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip complete!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort
Rip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip
Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Values to Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lookup Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DiskGauge</name>
    <message>
        <source>Free</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DiskRipper</name>
    <message>
        <source>Rip Disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CUT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disk Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Conflict</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>That cut has already been assigned a track!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A recording already exists.
Do you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ripping this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Data Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip complete!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Rip
Disc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Importer Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Ripper Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Total Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort
Rip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip
Disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip aborted!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Cart
Per Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Single
Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set
&amp;Cart/Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[continued]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify
Cart Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear
Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to allocate carts in group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to allocate cart in group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Values to Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lookup Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditCart</name>
    <message>
        <source>Number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Average Length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enforce Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forced Length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preserve Pitch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Artist:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Year Released:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>U&amp;sage:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduler Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Al&amp;bum:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Re&amp;cord Label:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lient:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A&amp;gency:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Publisher:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compos&amp;er:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;User Defined:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Execute Asynchronously</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit
Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AUDIO</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MACRO</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TFN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Missing Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must provide at least a Cart Title!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length Mismatch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One or more cut lengths exceed the timescaling
limits of the system!  Do you still want to save?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The cart title must be unique!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit
Notes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cond&amp;uctor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Song &amp;ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Beats per Minute:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By Specified Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By Weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schedule Cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The following cut order values are assigned more than once</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Cut Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Carts [multiple]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use RDLogManager Length for PAD Updates</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditMacro</name>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditNotes</name>
    <message>
        <source>Notes for cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditSchedulerCodes</name>
    <message>
        <source>Select Scheduler Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Assigned Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ASSIGN to Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>REMOVE from Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>Cart Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Data Dump (CSV)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prepend Field Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MacroCart</name>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Macros</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run
Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run
Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--- End of Cart ---</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>Please Wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Audio Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Macro Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Rip
CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Re&amp;ports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Are you sure you want to delete cart(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Cart(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart %06u is used in one or more RDCatch events!
Do you still want to delete it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDCatch Event Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting cart %06u will also empty the clipboard.
      	Do you still want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TFN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Note Bubbles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete audio!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Only First </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Matches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow Cart Dragging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Composer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conductor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Publisher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Agency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Defined</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Cut Played</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enforce Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preserve Pitch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length Deviation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Owned By</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Talk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run
&amp;Macro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>And Scheduler Code:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matching Carts:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecordCut</name>
    <message>
        <source>&amp;Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Outcue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ISRC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Played</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source># of Plays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut is EVERGREEN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Air Date/Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Daypart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Start Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Day of the Week</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Friday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Record Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoTrim</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VOX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will empty the clipboard.
Do you still want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must provide a Cut Description!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid ISRC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The ISRC data is malformed or invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Start Date is invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The End Date is invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The End Date is prior to the Start Date!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The End Date has already passed!
Do you still want to save?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Start Time is invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The End Time is invalid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The StartTime cannot be the same as the End Time!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to connect to Core AudioEngine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;ISCI Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AES ALARM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ingest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Info / Record</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
